# combo - content management system
# Copyright (C) 2014  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.contrib.contenttypes.models import ContentType

class Library(object):
    """Singleton object that serves as a registry of the classes
    providing page cells."""

    def __init__(self):
        self.classes = []
        self.classes_by_content_id = None

    def get_cell_classes(self):
        return self.classes

    def get_cell_class(self, content_type_id):
        if self.classes_by_content_id is None:
            # initialize the dictionary
            self.classes_by_content_id = {}
            for klass in self.classes:
                content_type = ContentType.objects.get_for_model(klass)
                self.classes_by_content_id[content_type.id] = klass
        return self.classes_by_content_id[int(content_type_id)]

    def register_cell_class(self, klass):
        self.classes.append(klass)
        return klass


library = Library() # singleton object
register_cell_class = library.register_cell_class
get_cell_classes = library.get_cell_classes
get_cell_class = library.get_cell_class
