# combo - content management system
# Copyright (C) 2014  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django import template

register = template.Library()

@register.inclusion_tag('combo/placeholder.html', takes_context=True)
def placeholder(context, placeholder_name):
    context['cells'] = [x for x in context['page_cells'] if
            x.placeholder == placeholder_name]
    return context

@register.simple_tag(takes_context=True)
def render_cell(context, cell):
    return cell.render(context)

@register.inclusion_tag('combo/menu.html', takes_context=True)
def show_menu(context, level=0):
    current_page = context['page']
    page_of_level = current_page.get_page_of_level(level)
    if page_of_level is None:
        if level > 0:
            parent_page = current_page.get_page_of_level(level-1)
            siblings = parent_page.get_children()
        else:
            context['menuitems'] = []
            return context
    else:
        siblings = page_of_level.get_siblings()
    menuitems = []
    for sibling in siblings:
        if not sibling.is_visible(context['request'].user):
            continue
        if sibling.exclude_from_navigation:
            continue
        menuitem = {'page': sibling}
        if sibling == page_of_level:
            menuitem['selected'] = True
        menuitems.append(menuitem)
    context['menuitems'] = menuitems
    return context
