from django.core.wsgi import get_wsgi_application
from webtest import TestApp
import pytest

from combo.data.models import Page, CellBase, TextCell

pytestmark = pytest.mark.django_db

def test_missing_index():
    Page.objects.all().delete()
    app = TestApp(get_wsgi_application())
    resp = app.get('/', status=404)

def test_index():
    Page.objects.all().delete()
    page = Page(title='Home', slug='index', template_name='standard')
    page.save()
    app = TestApp(get_wsgi_application())
    resp = app.get('/index', status=200)
    resp = app.get('/', status=200)

def test_page_contents():
    Page.objects.all().delete()
    page = Page(title='Home', slug='index', template_name='standard')
    page.save()
    cell = TextCell(page=page, placeholder='content', text='Foobar', order=0)
    cell.save()
    app = TestApp(get_wsgi_application())
    resp = app.get('/', status=200)
    assert 'Foobar' in resp.body

def test_page_footer_acquisition():
    Page.objects.all().delete()
    page = Page(title='Home', slug='index', template_name='standard')
    page.save()
    cell = TextCell(page=page, placeholder='footer', text='BARFOO', order=0)
    cell.save()
    app = TestApp(get_wsgi_application())
    resp = app.get('/', status=200)
    assert 'BARFOO' in resp.body

    page = Page(title='Second', slug='second', template_name='standard')
    page.save()
    resp = app.get('/second', status=200)
    assert 'BARFOO' in resp.body

def test_page_redirect():
    Page.objects.all().delete()
    page = Page(title='Elsewhere', slug='elsewhere', template_name='standard',
            redirect_url='http://example.net')
    page.save()
    app = TestApp(get_wsgi_application())
    resp = app.get('/elsewhere', status=302)
    assert resp.location == 'http://example.net'
